@@ -46,13 +46,6 @@
 #include <sys/types.h>
 #include <sys/socket.h>
 
-#include <bluetooth/bluetooth.h>
-#include <bluetooth/hci.h>
-#include <bluetooth/hci_lib.h>
-
-#include <bluetooth/sdp.h>
-#include <bluetooth/sdp_lib.h>
-
 #include <obexftp/obexftp.h>
 #include <obexftp/client.h>
 #include <obexftp/uuid.h>
@@ -93,75 +86,90 @@ static int nonblock = 0;
 
 static int discover_irda(void) { return -1; }
 
-static int discover_usb(void) { return -1; }
-
-static int discover_tty(char *UNUSED(port)) { return -1; }
-
-static int discover_bt(void)
-{
-	inquiry_info *info = NULL;
-	bdaddr_t bdswap;
-	char name[248], *bastr;
-	int dev_id = 0;
-	int num_rsp = 10;
-	int flags = 0;
-	int length = 8;
-	int dd, i;
+static int discover_usb(void) {
+	char **devices, **dev;
+	char name[25], *p;
 	connection_t *conn;
 
-	DEBUG("Scanning ...\n");
-	num_rsp = hci_inquiry(dev_id, length, num_rsp, NULL, &info, flags);
+	DEBUG("Scanning USB...\n");
+	devices = obexftp_discover(OBEX_TRANS_USB);
 
-	if(num_rsp < 0) {
-		perror("Inquiry failed.");
-		return -1;
-	}
-
-	if ((dd = hci_open_dev(dev_id)) < 0) {
-		perror("HCI device open failed");
-		free(info);
-		return -1;
-	}
-  
-	for(i = 0; i < num_rsp; i++) {
-		memset(name, 0, sizeof(name));
-
-		baswap(&bdswap, &(info+i)->bdaddr);
-       		bastr = batostr(&bdswap);
-
-		if(hci_read_remote_name(dd, &(info+i)->bdaddr, sizeof(name), name, 10000) < 0) {
-			strcpy(name, bastr);
-		}
+	for(dev = devices; *dev; dev++) {
+		strcpy(name, "usb");
+		strncpy(&name[3], *dev, sizeof(name)-4);
+		p = strchr(name, ' ');
+		if (p)
+			*p = '\0';
+       		DEBUG("Found %s (%d), %s\n", name, atoi(*dev), *dev);
 
 		for (conn = connections; conn; conn = conn->next) {
-	       		if (!strcmp(conn->addr, bastr)) {
+	       		if (!strcmp(conn->addr, name)) {
 				conn->recent++;
 				break;
 			}
 		}
 	
 		if (!conn) {
-			DEBUG("Adding\t%s\t%s\n", bastr, name);
+			DEBUG("Adding %s\n", name);
 			conn = calloc(1, sizeof(connection_t));
 			if (!conn)
 				return -1;
-			conn->alias = strdup(name);
+			conn->alias = NULL;
+			conn->transport = OBEX_TRANS_USB;
+			conn->addr = strdup(name);
+			conn->channel = atoi(*dev);
+			//conn->cli = cli_open(OBEX_TRANS_USB, NULL, conn->channel);
+       			conn->recent++;
+			conn->next = connections;
+			connections = conn;
+		}
+	}
+	return 0;
+}
+
+static int discover_tty(char *UNUSED(port)) { return -1; }
+
+static int discover_bt(void)
+{
+	char *hci = NULL;
+	char **devs, **dev, *name;
+	connection_t *conn;
+
+	DEBUG("Scanning ...\n");
+	devs = obexftp_discover_bt_src(hci);
+
+	if(!devs) {
+		perror("Inquiry failed.");
+		return -1;
+	}
+  
+	for(dev = devs; dev && *dev; dev++) {
+		for (conn = connections; conn; conn = conn->next) {
+	       		if (!strcmp(conn->addr, *dev)) {
+				conn->recent++;
+				break;
+			}
+		}
+	
+		if (!conn) {
+			name = obexftp_bt_name_src(*dev, hci);
+			DEBUG("Adding\t%s\t%s\n", *dev, name);
+			conn = calloc(1, sizeof(connection_t));
+			if (!conn)
+				return -1;
+			conn->alias = name;
 			conn->transport = OBEX_TRANS_BLUETOOTH;
-			conn->addr = bastr;
-			conn->channel = 5; // Siemens
-			conn->channel = 10; // Nokia
-			conn->channel = 6; // Sony-Ericsson
-			//conn->cli = cli_open(OBEX_TRANS_BLUETOOTH, batostr(&bdswap), 5);
+			conn->addr = *dev;
+			conn->channel = obexftp_browse_bt_ftp(conn->addr);
+			//conn->cli = cli_open(OBEX_TRANS_BLUETOOTH, conn->addr, conn->channel);
        			conn->recent++;
 			conn->next = connections;
 			connections = conn;
 		} else
-			free(bastr);
+			free(*dev);
 	}
   
-	close(dd);
-	free(info);
-  
+	free(devs);
 	return 0;
 }
 
@@ -185,12 +193,13 @@ static int discover_devices(void) {
 	
 	/* remove from head */
 	while (connections && connections->recent == 0) {
-		fprintf(stderr, "Deleting %s\n", connections->alias);
+		DEBUG("Deleting %s\n", connections->addr);
        		conn = connections;
        		connections = conn->next;
        	
        		cli_close(conn->cli);
-       		free(conn->alias);
+		if (conn->alias)
+	       		free(conn->alias);
        		free(conn->addr);
        		free(conn);
        	}
@@ -198,12 +207,13 @@ static int discover_devices(void) {
 	/* remove from body */
 	for (prev = connections; prev; prev = prev->next)
 		if(prev->next && prev->next->recent == 0) {
-		fprintf(stderr, "Deleting2 %s\n", prev->next->alias);
+		DEBUG("Deleting2 %s\n", prev->next->addr);
 	       		conn = prev->next;
        			prev->next = conn->next;
        	
        			cli_close(conn->cli);
-	       		free(conn->alias);
+			if (conn->alias)
+	       			free(conn->alias);
        			free(conn->addr);
 	       		free(conn);
 		}
@@ -304,7 +314,7 @@ static connection_t *ofs_find_connection(const char *path, char **filepath)
 		namelen = strlen(path);
 	
 	for (conn = connections; conn; conn = conn->next) {
-        	if (!strncmp(conn->addr, path, namelen) || !strncmp(conn->alias, path, namelen)) {
+        	if (!strncmp(conn->addr, path, namelen) || (conn->alias && !strncmp(conn->alias, path, namelen))) {
 			if (!conn->cli)
 				conn->cli = cli_open(conn->transport, conn->addr, conn->channel);
 			return conn;
@@ -358,7 +368,7 @@ static int ofs_getattr(const char *path, struct stat *stbuf)
 	
 	if(!filepath) {
 		/* the device entry itself */
-		if (strchr(path, ':'))
+		if (!strcmp(path + 1, conn->addr))
 			stbuf->st_mode = S_IFDIR | 0755;
 		else
 			stbuf->st_mode = S_IFLNK | 0777;
@@ -401,7 +411,7 @@ static int ofs_readlink (const char *path, char *link, size_t UNUSED(size))
 	connection_t *conn;
 
 	for (conn = connections; conn; conn = conn->next) {
-		if(!strcmp(conn->alias, path + 1)) {
+		if(conn->alias && !strcmp(conn->alias, path + 1)) {
 			strcpy(link, conn->addr);
 			return 0;
 		}
@@ -431,7 +441,8 @@ static int ofs_getdir(const char *path, fuse_dirh_t h, fuse_dirfil_t filler)
 		res = filler(h, "..", DT_DIR, 0);
 		for (conn = connections; conn; conn = conn->next) {
 			stat.st_mode = DT_DIR;
-			res = filler(h, conn->alias, DT_LNK, 0);
+			if (conn->alias)
+				res = filler(h, conn->alias, DT_LNK, 0);
 			res = filler(h, conn->addr, DT_DIR, 0);
 			if(res != 0)
 				break;
@@ -742,7 +753,8 @@ static void ofs_destroy(void *UNUSED(private_data)) {
         /* Close connection */
 	for (conn = connections; conn; conn = conn->next) {
 		cli_close(conn->cli);
-       		free(conn->alias);
+		if (conn->alias)
+       			free(conn->alias);
        		free(conn->addr);
        		free(conn);
 	}
