@@ -66,7 +66,7 @@ struct data_buffer {
 static obexftp_client_t *cli = NULL;
 static int transport = 0;
 static char *device = NULL; // "00:11:22:33:44:55"; "/dev/ttyS0";
-static int channel = 6; // 10;
+static int channel = -1;
 
 static int nonblock = 0;
 
@@ -89,6 +89,10 @@ static int cli_open()
                 return -1;
         }
 
+	if (channel < 0) {
+		channel = obexftp_browse_bt_ftp(device);
+	}
+
         for (retry = 0; retry < 3; retry++) {
 
                 /* Connect */
@@ -522,17 +526,14 @@ int main(int argc, char *argv[])
 		
 		case 'i':
 			transport = OBEX_TRANS_IRDA;
-			if (device != NULL)
-				free(device);
 			device = NULL;
 			channel = 0;
 			break;
 		
 		case 'b':
 			transport = OBEX_TRANS_BLUETOOTH;
-			if (device != NULL)
-				free (device);
-       			device = optarg;
+			device = optarg;
+			channel = -1;
 			break;
 			
 		case 'B':
@@ -543,27 +544,18 @@ int main(int argc, char *argv[])
 			if (geteuid() != 0)
 				fprintf(stderr, "If USB doesn't work setup permissions in udev or run as superuser.\n");
 			transport = OBEX_TRANS_USB;
-			if (device != NULL)
-				free(device);
 			device = NULL;
 			channel = atoi(optarg);
 			break;
 		
 		case 't':
 			transport = OBEX_TRANS_CUSTOM;
-			if (device != NULL)
-				free(device);
-			device = NULL;
+			device = optarg;
 			channel = 0;
-
-			if (strcasecmp(optarg, "irda"))
-				device = optarg;
 			break;
 			
 		case 'n':
 			transport = OBEX_TRANS_INET;
-			if (device != NULL)
-				free(device);
 			device = optarg;
 			channel = 650;
 			{
